==> web_host_metadata-1.0.0.tar.gz: web_host_metadata/src/EventSubscriber/WebHostMetadataSubscriber.php <==
<?php

namespace Drupal\web_host_metadata\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\Extension\ModuleHandler;
use Drupal\Core\Url;
use Drupal\web_host_metadata\Event\WebHostMetadataEvents;
use Drupal\web_host_metadata\Event\WebHostMetadataResponseEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Web Host Metadata event subscriber.
 */
class WebHostMetadataSubscriber implements EventSubscriberInterface {

  /**
   * The immutable config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected ImmutableConfig $config;

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandler
   */
  protected ModuleHandler $moduleHandler;

  /**
   * Constructs a WebHostMetadataSubscriber object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Extension\ModuleHandler $module_handler
   *   The module handler.
   */
  public function __construct(ConfigFactoryInterface $config_factory, ModuleHandler $module_handler) {
    $this->config = $config_factory->get('web_host_metadata.settings');
    $this->moduleHandler = $module_handler;
  }

  /**
   * The event callback.
   *
   * @param \Drupal\web_host_metadata\Event\WebHostMetadataResponseEvent $event
   *   The response event.
   */
  public function onWebHostMetadataResponse(WebHostMetadataResponseEvent $event) {
    $xrd = $event->getXrd();

    // Add support for webfinger module ftb.
    if ($this->moduleHandler->moduleExists('webfinger')) {
      $url = Url::fromRoute('webfinger.well-known', [], ['absolute' => TRUE])->toString(TRUE);
      $xrd->links[] = new \XML_XRD_Element_Link(
        'lrdd', $url->getGeneratedUrl() . '?resource={uri}',
        'application/json', TRUE
      );
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      WebHostMetadataEvents::RESPONSE => ['onWebHostMetadataResponse'],
    ];
  }

}

==> web_host_metadata-1.0.1.tar.gz: web_host_metadata/src/EventSubscriber/WebHostMetadataSubscriber.php <==
<?php

namespace Drupal\web_host_metadata\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\Extension\ModuleHandler;
use Drupal\Core\Url;
use Drupal\web_host_metadata\Event\WebHostMetadataEvents;
use Drupal\web_host_metadata\Event\WebHostMetadataResponseEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Web Host Metadata event subscriber.
 */
class WebHostMetadataSubscriber implements EventSubscriberInterface {

  /**
   * The immutable config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected ImmutableConfig $config;

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandler
   */
  protected ModuleHandler $moduleHandler;

  /**
   * Constructs a WebHostMetadataSubscriber object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Extension\ModuleHandler $module_handler
   *   The module handler.
   */
  public function __construct(ConfigFactoryInterface $config_factory, ModuleHandler $module_handler) {
    $this->config = $config_factory->get('web_host_metadata.settings');
    $this->moduleHandler = $module_handler;
  }

  /**
   * The event callback.
   *
   * @param \Drupal\web_host_metadata\Event\WebHostMetadataResponseEvent $event
   *   The response event.
   */
  public function onWebHostMetadataResponse(WebHostMetadataResponseEvent $event) {
    $xrd = $event->getXrd();

    // Add support for webfinger module ftb.
    if ($this->moduleHandler->moduleExists('webfinger')) {

      // Check if webfinger link is already there.
      foreach ($xrd->getAll('lrdd') as $link) {
        if (strpos($link->template, '/.well-known/webfinger')) {
          return;
        }
      }

      // Add webfinger link.
      $url = Url::fromRoute('webfinger.well-known', [], ['absolute' => TRUE])->toString(TRUE);
      $xrd->links[] = new \XML_XRD_Element_Link(
        'lrdd', $url->getGeneratedUrl() . '?resource={uri}',
        'application/json', TRUE
      );
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      WebHostMetadataEvents::RESPONSE => ['onWebHostMetadataResponse', -100],
    ];
  }

}
